@@ -1,6 +1,3 @@
-import os
-
-os.environ["PYGAME_HIDE_SUPPORT_PROMPT"] = "hide"
 import math
 import os
 
@@ -9,6 +6,8 @@ import pygame
 from .img import get_image
 from .weapons import Arrow, Sword
 
+os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = 'hide'
+
 WIDTH = 1280
 HEIGHT = 720
 ARCHER_SPEED = 25
@@ -19,9 +18,10 @@ ANGLE_RATE = 10
 
 
 class Archer(pygame.sprite.Sprite):
+
     def __init__(self, agent_name):
         super().__init__()
-        self.image = get_image(os.path.join("img", "archer.png"))
+        self.image = get_image(os.path.join('img', 'archer.png'))
         self.rect = self.image.get_rect(center=(ARCHER_X, ARCHER_Y))
         self.org_image = self.image.copy()
         self.angle = 0
@@ -81,7 +81,7 @@ class Archer(pygame.sprite.Sprite):
 class Knight(pygame.sprite.Sprite):
     def __init__(self, agent_name):
         super().__init__()
-        self.image = get_image(os.path.join("img", "knight.png"))
+        self.image = get_image(os.path.join('img', 'knight.png'))
         self.rect = self.image.get_rect(center=(KNIGHT_X, KNIGHT_Y))
         self.org_image = self.image.copy()
         self.angle = 0
